@@ -10,8 +10,8 @@ def thumb_querie(id:int) -> typing.Union[tuple, str]:
     connection = psycopg2.connect(**db_parameters)
     try:
         cursor = connection.cursor()
-        select_command = "SELECT * FROM picturereference WHERE id=%(int)s;"
-        cursor.execute(select_command, id)
+        select_command = f"SELECT * FROM picturereference WHERE id={int(id)};"
+        cursor.execute(select_command)
         pic_ref = cursor.fetchone()[0]
     except Exception as e:
         return e
